/*
    SHOW:  A test application for the SDL image loading library.
    Copyright (C) 1999  Sam Lantinga

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Sam Lantinga
    5635-34 Springhouse Dr.
    Pleasanton, CA 94588 (USA)
    slouken@devolution.com
*/

#include <stdlib.h>
#include <stdio.h>

#include "SDL.h"
#include "SDL_image.h"


main(int argc, char *argv[])
{
	SDL_Surface *screen, *image;
	int i;

	/* Check command line usage */
	if ( ! argv[1] ) {
		fprintf(stderr, "Usage: %s <image_file>\n", argv[0]);
		exit(1);
	}

	/* Initialize the SDL library */
	if ( SDL_Init(SDL_INIT_VIDEO) < 0 ) {
		fprintf(stderr, "Couldn't initialize SDL: %s\n",SDL_GetError());
		exit(255);
	}
	atexit(SDL_Quit);

	/* Open the image file */
	image = IMG_Load(argv[1]);
	if ( image == NULL ) {
		fprintf(stderr,"Couldn't load %s: %s\n",argv[1],SDL_GetError());
		exit(2);
	}

	/* Create a display for the image */
	screen = SDL_SetVideoMode(image->w, image->h, 0, SDL_SWSURFACE);
	if ( screen == NULL ) {
		fprintf(stderr,"Couldn't set %dx%d video mode: %s\n",
				image->w, image->h, SDL_GetError());
		exit(3);
	}

	/* Set the palette, if one exists */
	if ( image->format->palette ) {
		SDL_SetColors(screen, image->format->palette->colors,
				0, image->format->palette->ncolors);
	}

	/* Display the image */
	SDL_BlitSurface(image, NULL, screen, NULL);
	SDL_UpdateRect(screen, 0, 0, 0, 0);

	/* Wait for any keyboard or mouse input */
	for ( i=SDL_NOEVENT; i<SDL_NUMEVENTS; ++i ) {
		switch (i) {
		    case SDL_KEYDOWN:
		    case SDL_MOUSEBUTTONDOWN:
		    case SDL_QUIT:
			/* Valid event, keep it */
			break;
		    default:
			/* We don't want this event */
			SDL_EventState(i, SDL_IGNORE);
			break;
		}
	}
	SDL_WaitEvent(NULL);

	/* We're done! */
	SDL_FreeSurface(image);
	exit(0);
}
